@@ -57,9 +57,8 @@ class PartialPageMiddleware(object):
 		json_obj = dict(
 			(key, _thread_locals.partial[key])
 			for key in ['blocks', 'data']
-			if len(_thread_locals.partial[key]) > 0
-		)
-		
+			if len(_thread_locals.partial[key]) > 0)
+
 		new_response = HttpResponse(json.dumps(json_obj), mimetype='application/json')
 		new_response.status_code = response.status_code
 		return new_response
